==> csaw_1.14.1.tar.gz: csaw/man/consolidateClusters.Rd <==
\name{consolidateClusters}
\alias{consolidateClusters}

\title{Consolidate DB clusters}
\description{Consolidate DB results from multiple analyses with cluster-level FDR control.}

\usage{
consolidateClusters(data.list, result.list, equiweight=TRUE, ...)
}

\arguments{
\item{data.list}{a list of RangedSummarizedExperiment and/or GRanges objects}
\item{result.list}{a list of data frames containing the DB test results for each entry of \code{data.list}}
\item{equiweight}{a logical scalar indicating whether equal weighting from each analysis should be enforced}
\item{...}{arguments to be passed to \code{\link{clusterWindows}}}
}

\value{
A named list is returned containing:
\item{id}{a list of integer vectors indicating the cluster ID for each window in \code{data.list}}
\item{region}{a GRanges object containing the coordinates for each cluster}
\item{FDR}{a numeric scalar containing the cluster-level FDR estimate}
}

\details{
This function consolidates DB results from multiple analyses, typically involving different window sizes.
The aim is to provide comprehensive detection of DB at a range of spatial resolutions.
Significant windows from each analysis are identified and used for clustering with \code{\link{clusterWindows}}.
This represents the post-hoc counterpart to \code{\link{consolidateSizes}}.

Some effort is required to equalize the contribution of the results from each analysis.
This is done by setting \code{equiweight=TRUE}, where the weight of each window is inversely proportional to the number of windows from that analysis.
These weights are used as frequency weights for window-level FDR control (to identify DB windows prior to clustering).
Otherwise, the final results would be dominated by large number of small windows.

Users can cluster by the sign of log-fold changes, to obtain clusters of DB windows of the same sign.
However, note that nested windows with opposite signs may give unintuitive results - see \code{\link{mergeWindows}} for details.
}

\seealso{
\code{\link{clusterWindows}},
\code{\link{consolidateSizes}}
}

\author{
Aaron Lun
}

\examples{
# Making up some GRanges.
low <- GRanges("chrA", IRanges(runif(100, 1, 1000), width=5))
med <- GRanges("chrA", IRanges(runif(40, 1, 1000), width=10))
high <- GRanges("chrA", IRanges(runif(10, 1, 1000), width=20))

# Making up some DB results.
dbl <- data.frame(logFC=rnorm(length(low)), PValue=rbeta(length(low), 1, 20))
dbm <- data.frame(logFC=rnorm(length(med)), PValue=rbeta(length(med), 1, 20))
dbh <- data.frame(logFC=rnorm(length(high)), PValue=rbeta(length(high), 1, 20))
result.list <- list(dbl, dbm, dbh)

# Consolidating.
cons <- consolidateClusters(list(low, med, high), result.list, tol=20)
cons$region
cons$id
cons$FDR

# Without weights.
cons <- consolidateClusters(list(low, med, high), result.list, tol=20, equiweight=FALSE)
cons$FDR

# Using the signs.
cons <- consolidateClusters(list(low, med, high), result.list, tol=20, fc.col="logFC")
}

\keyword{clustering}

==> csaw_1.18.0.tar.gz: csaw/man/consolidateClusters.Rd <==
\name{consolidateClusters}
\alias{consolidateClusters}

\title{Consolidate DB clusters}
\description{Consolidate DB results from multiple analyses with cluster-level FDR control.}

\usage{
consolidateClusters(data.list, result.list, equiweight=TRUE, ...)
}

\arguments{
\item{data.list}{a list of RangedSummarizedExperiment and/or GRanges objects}
\item{result.list}{a list of data frames containing the DB test results for each entry of \code{data.list}}
\item{equiweight}{a logical scalar indicating whether equal weighting from each analysis should be enforced}
\item{...}{arguments to be passed to \code{\link{clusterWindows}}}
}

\value{
A named list is returned containing:
\item{id}{a list of integer vectors indicating the cluster ID for each window in \code{data.list}}
\item{region}{a GRanges object containing the coordinates for each cluster}
\item{FDR}{a numeric scalar containing the cluster-level FDR estimate}
}

\details{
This function consolidates DB results from multiple analyses, typically involving different window sizes.
The aim is to provide comprehensive detection of DB at a range of spatial resolutions.
Significant windows from each analysis are identified and used for clustering with \code{\link{clusterWindows}}.
This represents the post-hoc counterpart to \code{\link{consolidateWindows}}.

Some effort is required to equalize the contribution of the results from each analysis.
This is done by setting \code{equiweight=TRUE}, where the weight of each window is inversely proportional to the number of windows from that analysis.
These weights are used as frequency weights for window-level FDR control (to identify DB windows prior to clustering).
Otherwise, the final results would be dominated by large number of small windows.

Users can cluster by the sign of log-fold changes, to obtain clusters of DB windows of the same sign.
However, note that nested windows with opposite signs may give unintuitive results - see \code{\link{mergeWindows}} for details.
}

\seealso{
\code{\link{clusterWindows}},
\code{\link{consolidateWindows}}
}

\author{
Aaron Lun
}

\examples{
# Making up some GRanges.
low <- GRanges("chrA", IRanges(runif(100, 1, 1000), width=5))
med <- GRanges("chrA", IRanges(runif(40, 1, 1000), width=10))
high <- GRanges("chrA", IRanges(runif(10, 1, 1000), width=20))

# Making up some DB results.
dbl <- data.frame(logFC=rnorm(length(low)), PValue=rbeta(length(low), 1, 20))
dbm <- data.frame(logFC=rnorm(length(med)), PValue=rbeta(length(med), 1, 20))
dbh <- data.frame(logFC=rnorm(length(high)), PValue=rbeta(length(high), 1, 20))
result.list <- list(dbl, dbm, dbh)

# Consolidating.
cons <- consolidateClusters(list(low, med, high), result.list, tol=20)
cons$region
cons$id
cons$FDR

# Without weights.
cons <- consolidateClusters(list(low, med, high), result.list, tol=20, equiweight=FALSE)
cons$FDR

# Using the signs.
cons <- consolidateClusters(list(low, med, high), result.list, tol=20, fc.col="logFC")
}

\keyword{clustering}
